==> floating_block-6.x-1.1.tar.gz: floating_block/floating_block.js <==
// $Id: floating_block.js,v 1.1 2010/06/01 08:50:56 alexpott Exp $

/**
 * Provides the ability to fix a html block to a position on the page when the 
 * browser is scroled.
 *
 * This code is based on tableheader.js
 */

Drupal.blockFloatDoScroll = function() {
  if (typeof(Drupal.blockFloatOnScroll)=='function') {
    Drupal.blockFloatOnScroll();
  }
};

/**
 * Attaches the floating_block behavior.
 */
Drupal.behaviors.blockFloat = function (context) {
  // This breaks in anything less than IE 7. Prevent it from running.
  if (jQuery.browser.msie && parseInt(jQuery.browser.version, 10) < 7) {
    return;
  }
  
  // Keep track of all cloned blocks.
  var blocks = [];
  $(Drupal.settings.floating_block).each(function (i, selector) {
    $(selector.toString() +':not(.blockFloat-processed)', context).each(function (j, block) {
      // Clone thead so it inherits original jQuery properties.
      var blockClone = $(block).clone(true).insertBefore(block).addClass('sticky-block').css({
        position: 'fixed',
        top: '0px',
        width: $(this).width(),
        height: $(this).height(),
        visibility: 'hidden'
      });

      if ($(block).attr('id').length > 0) {
        $(blockClone).attr('id',$(block).attr('id') + '-clone');
      }
      blockClone = $(blockClone)[0];
      blockClone.original_position = $(block).offset();
      blocks.push(blockClone);

      // Finish initialzing header positioning.
      tracker(blockClone);

      //Maybe need to attach soemthing to parent div?
      //$(table).addClass('sticky-table');
      $(block).addClass('blockFloat-processed');
    });
  });

  // Define the anchor holding var.
  var prevAnchor = '';

  // Track positioning and visibility.
  function tracker(e) {
    // Save positioning data.
    var viewHeight = document.documentElement.scrollHeight || document.body.scrollHeight;
    if (e.viewHeight != viewHeight) {
      e.viewHeight = viewHeight;
      e.docHeight = $(document).height();
      e.vPosition = e.original_position.top;
      e.hPosition = e.original_position.left;
      e.vLength = e.clientHeight;
    }
    var current_position = $(e).offset();
    // Track horizontal positioning relative to the viewport and set visibility.
    var hScroll = document.documentElement.scrollLeft || document.body.scrollLeft;
    var vOffset = (document.documentElement.scrollTop || document.body.scrollTop) - e.vPosition;

    var topPosition = 0;
    if (vOffset > 0) {
      visState = 'visible';
      $('#sidebar-left-inner').css({visibility: 'hidden'});
      //Don't let the bottom of the block go beneath the document height
      if ((current_position.top + e.vLength) > e.docHeight) {
         topPosition = e.docHeight - current_position.top - e.vLength;
      }
    }
    else {
      visState = 'hidden';
      $('#sidebar-left-inner').css({visibility: 'visible'});
    }

    $(e).css({left: -hScroll + e.hPosition +'px', visibility: visState, top: topPosition +'px'});

  }

  // Only attach to scrollbars once, even if Drupal.attachBehaviors is called
  //  multiple times.
  if (!$('body').hasClass('blockFloat-processed')) {
    $('body').addClass('blockFloat-processed');
    $(window).scroll(Drupal.blockFloatDoScroll);
    $(document.documentElement).scroll(Drupal.blockFloatDoScroll);
  }

  // Track scrolling.
  Drupal.blockFloatOnScroll = function() {
    $(blocks).each(function () {
      tracker(this);
    });
  };

  // Track resizing.
  var time = null;
  var resize = function () {
    // Ensure minimum time between adjustments.
    if (time) {
      return;
    }
    time = setTimeout(function () {
      $('.sticky-block').each(function () {
        this.viewHeight = 0;
        tracker(this);
      });
      // Reset timer
      time = null;
    }, 250);
  };
  $(window).resize(resize);
};

==> floating_block-6.x-1.2.tar.gz: floating_block/floating_block.js <==
// $Id: floating_block.js,v 1.1.2.1 2010/08/29 05:47:11 alexpott Exp $

/**
 * Provides the ability to fix a html block to a position on the page when the 
 * browser is scroled.
 *
 * This code is based on tableheader.js
 */

Drupal.blockFloatDoScroll = function () {
  if (typeof(Drupal.blockFloatOnScroll) == 'function') {
    Drupal.blockFloatOnScroll();
  }
};

/**
 * Attaches the floating_block behavior.
 */
Drupal.behaviors.blockFloat = function (context) {
  // This breaks in anything less than IE 7. Prevent it from running.
  if (jQuery.browser.msie && parseInt(jQuery.browser.version, 10) < 7) {
    return;
  }
  
  // Keep track of all cloned blocks.
  var blocks = [];
  $(Drupal.settings.floating_block).each(function (i, selector) {
    $(selector.toString() + ':not(.blockFloat-processed)', context).each(function (j, block) {
      // Clone thead so it inherits original jQuery properties.
      var blockClone = $(block).clone(true).insertBefore(block).addClass('sticky-block').css({
        position: 'fixed',
        top: '0px',
        width: $(this).width(),
        height: $(this).height(),
        visibility: 'hidden'
      });

      if ($(block).attr('id').length > 0) {
        $(blockClone).attr('id',$(block).attr('id') + '-clone');
      }
      blockClone = $(blockClone)[0];
      blockClone.original_position = $(block).offset();
      blockClone.original_identifier = 'blockFloat-' + blocks.length;
      blocks.push(blockClone);

      // Finish initialzing header positioning.
      tracker(blockClone);

      //Maybe need to attach soemthing to parent div?
      //$(table).addClass('sticky-table');
      $(block).addClass('blockFloat-processed ' + blockClone.original_identifier);
    });
  });

  // Track positioning and visibility.
  function tracker(e) {
    // Save positioning data.
    var viewHeight = document.documentElement.scrollHeight || document.body.scrollHeight;
    if (e.viewHeight != viewHeight) {
      e.viewHeight = viewHeight;
      e.docHeight = $(document).height();
      e.vPosition = e.original_position.top;
      e.hPosition = e.original_position.left;
      e.vLength = e.clientHeight;
    }
    var current_position = $(e).offset();
    // Track horizontal positioning relative to the viewport and set visibility.
    var hScroll = document.documentElement.scrollLeft || document.body.scrollLeft;
    var vOffset = (document.documentElement.scrollTop || document.body.scrollTop) - e.vPosition;

    var topPosition = 0;
    if (vOffset > 0) {
      visState = 'visible';
      $('.' + e.original_identifier).css({visibility: 'hidden'});
      //Don't let the bottom of the block go beneath the document height
      if ((current_position.top + e.vLength) > e.docHeight) {
         topPosition = e.docHeight - current_position.top - e.vLength;
      }
    }
    else {
      visState = 'hidden';
      $('.' + e.original_identifier).css({visibility: 'visible'});
    }

    $(e).css({left: -hScroll + e.hPosition + 'px', visibility: visState, top: topPosition + 'px'});

  }

  // Only attach to scrollbars once, even if Drupal.attachBehaviors is called
  //  multiple times.
  if (!$('body').hasClass('blockFloat-processed')) {
    $('body').addClass('blockFloat-processed');
    $(window).scroll(Drupal.blockFloatDoScroll);
    $(document.documentElement).scroll(Drupal.blockFloatDoScroll);
  }

  // Track scrolling.
  Drupal.blockFloatOnScroll = function() {
    $(blocks).each(function () {
      tracker(this);
    });
  };

  // Track resizing.
  var time = null;
  var resize = function () {
    // Ensure minimum time between adjustments.
    if (time) {
      return;
    }
    time = setTimeout(function () {
      $('.sticky-block').each(function () {
        this.viewHeight = 0;
        tracker(this);
      });
      // Reset timer
      time = null;
    }, 250);
  };
  $(window).resize(resize);
};
